<?php namespace EscapeWork\Manager\Banners\Controllers;

use EscapeWork\Manager\Controllers\ManagerController;
use EscapeWork\Manager\Banners\Repositories\BannerRepository;
use EscapeWork\Manager\Banners\Repositories\BannerGroupRepository;
use View;
use Input;
use Redirect;
use Response;
use Config;

class BannersController extends ManagerController
{

    public function __construct(BannerRepository $banner, BannerGroupRepository $bannerGroup)
    {
        $this->banner      = $banner;
        $this->bannerGroup = $bannerGroup;

        # filters
        $this->validatePermissions('banners');

        View::share('page', 'banners');
    }

    public function index()
    {
        $view          = View::make(Config::get('manager-banners::views.banners.index'));
        $view->banners = $this->banner->filterAndFetch(Input::all());
        $view->groups  = $this->bannerGroup->all();

        return $view;
    }

    public function create()
    {
        $this->banner->fill(Input::old());

        $view         = View::make(Config::get('manager-banners::views.banners.form'));
        $view->banner = $this->banner;
        $view->groups = $this->bannerGroup->all();
        $view->edit   = false;

        return $view;
    }

    public function store()
    {
        $this->banner->fill(Input::all());

        if (! $this->banner->validate()) {
            return Redirect::route('manager.banners.create')
                    ->withInput()
                    ->withErrors($this->banner->messages());
        }

        if (! $this->banner->uploadBanner(Input::file('banner'))) {
            return Redirect::route('manager.banners.create')
                    ->withInput()
                    ->withErrors($this->banner->messages());
        }

        $this->banner->save();

        return Redirect::route('manager.banners.index', array('banner_group_id' => $this->banner->banner_group_id))
                       ->with('message', 'O banner <strong>'.$this->banner->title.'</strong> foi inserido com sucesso!');
    }

    public function edit($id)
    {
        $this->banner = $this->banner->findOrFail($id);
        $this->banner->fill(Input::old());

        $view         = View::make(Config::get('manager-banners::views.banners.form'));
        $view->banner = $this->banner;
        $view->groups = $this->bannerGroup->all();
        $view->edit   = true;

        return $view;
    }

    public function update($id)
    {
        $this->banner = $this->banner->findOrFail($id);
        $this->banner->fill(Input::all());

        if (! $this->banner->validate()) {
            return Redirect::route('manager.banners.edit', $this->banner->id)
                    ->withInput()
                    ->withErrors($this->banner->messages());
        }

        $this->banner->uploadBanner(Input::file('banner'));
        $this->banner->save();

        return Redirect::route('manager.banners.index', array('banner_group_id' => $this->banner->banner_group_id))
                ->with('message', 'O banner <strong>'.$this->banner->title.'</strong> foi editado com sucesso!');
    }

    public function destroy($id)
    {
        $this->banner = $this->banner->findOrFail($id);
        $this->banner->delete();

        return Redirect::route('manager.banners.index')
                ->with('message', 'O banner <strong>'.$this->banner->title.'</strong> foi excluído com sucesso!');
    }

    public function updateActive($id)
    {
        if (! $this->banner = $this->banner->find($id)) {
            return Response::json(array(
                'error' => 'Banner não encontrado'
            ));
        }

        $this->banner->active = Input::get('active');
        $this->banner->save();

        return Response::json(array(
            'message' => 'O banner foi atualizado com sucesso'
        ));
    }

    public function updateOrder($id)
    {
        if (! $this->banner = $this->banner->find($id)) {
            return Response::json(array(
                'error' => 'Banner não encontrado'
            ));
        }

        $this->banner->order = Input::get('order');
        $this->banner->save();

        return Response::json(array(
            'message' => 'O banner foi atualizado com sucesso'
        ));
    }

    /**
     * Returning the banner sizes
     */
    public function sizes($banner_group_id)
    {
        if ($this->bannerGroup = $this->bannerGroup->find($banner_group_id)) {
            return $this->bannerGroup->sizes->defaultSize();
        }

        return Response::json(Config::get('manager-banners::sizes.default.default'));
    }
}
