@extends(Config::get('manager::views.layouts.master'))

@section('content')
    {{
        Form::manager_breadcrumb(array(
            route('manager.banners.index') => 'Banners',
            $edit ? 'Editar banner' : 'Inserir banner'
        ))
    }}

    {{
        Form::manager_page_header(
            'Banners',
            $edit ? 'Editar banner' : 'Inserir banner',
            array(
                'route' => route('manager.banners.index', array('banner_group_id' => Input::get('banner_group_id'))),
                'label' => 'Cancelar',
            )
        )
    }}

    @include('manager::inc.messages')

    <form action="{{ !$edit ? route('manager.banners.store') : route('manager.banners.update', $banner->id) }}" method="post" id="form-banner" class="form-horizontal" enctype="multipart/form-data">
        @if ($edit)
            <input type="hidden" name="_method" value="put">
        @endif

        <fieldset>
            @section('fields')
                @if ($groups->count() > 0)
                    <div class="form-group">
                        <label for="banner_group_id" class="col-sm-2 control-label">Grupo</label>

                        <div class="col-sm-8">
                            {{ Form::select('banner_group_id', $groups->combobox(), $banner->banner_group_id ?: Input::get('banner_group_id'), ['id' => 'banner_group_id', 'class' => 'form-control']) }}
                        </div><!-- .col-sm-8 -->
                    </div><!-- .form-group -->
                @endif

                <div class="form-group">
                    <label for="title" class="col-sm-2 control-label">Título</label>

                    <div class="col-sm-8">
                        <input type="text" name="title" id="title" class="form-control" value="{{ $banner->title }}" maxlength="255" required autofocus>
                        <span class="help-block">Utilizado para controle interno apenas</span>
                    </div><!-- .col-sm-8 -->
                </div><!-- .form-group -->

                @if (! in_array('description', Config::get('manager-banners::hidden')))
                    <div class="form-group">
                        <label for="description" class="col-sm-2 control-label">Descrição</label>

                        <div class="col-sm-8">
                            <textarea name="description" id="description" class="form-control" rows="3">{{ $banner->description }}</textarea>
                        </div><!-- .col-sm-8 -->
                    </div><!-- .form-group -->
                @endif

                <div class="form-group">
                    <label for="link" class="col-sm-2 control-label">Link</label>

                    <div class="col-sm-8">
                        <div class="input-group">
                            <span class="input-group-addon">http://</span>
                            <input type="text" name="link" id="link" class="form-control" value="{{ str_replace('http://', '', $banner->link) }}" maxlength="255">
                        </div>
                    </div><!-- .col-sm-8 -->
                </div><!-- .form-group -->

                @if (! in_array('link_description', Config::get('manager-banners::hidden')))
                    <div class="form-group">
                        <label for="link_description" class="col-sm-2 control-label">Texto do link</label>

                        <div class="col-sm-8">
                            <textarea name="link_description" id="link_description" class="form-control" rows="2">{{ $banner->link_description }}</textarea>
                            <span class="help-block">Texto que vai aparecer no botão do link</span>
                        </div><!-- .col-sm-8 -->
                    </div><!-- .form-group -->
                @endif

                <div class="form-group">
                    <label for="link" class="col-sm-2 control-label">Abrir o link</label>

                    <div class="col-sm-8">
                        <div class="radio">
                            <label>
                                <input type="radio" name="target" value="_self" {{ $banner->target != '_blank' ? 'checked="checked"' : null }}>
                                Na mesma janela
                            </label>
                        </div>

                        <div class="radio">
                            <label>
                                <input type="radio" name="target" value="_blank" {{ $banner->target == '_blank' ? 'checked="checked"' : null }}>
                                Em outra janela
                            </label>
                        </div>
                    </div><!-- .col-sm-8 -->
                </div><!-- .form-group -->

                <div class="form-group">
                    <label for="banner" class="col-sm-2 control-label">Banner</label>

                    <div class="col-sm-8">
                        <input type="file" name="banner" id="banner" class="form-control" accept="{{ implode(',', $banner->getAcceptedImages()) }}" {{ !$edit ? 'required' : null }}>

                        <span class="help-block">Apenas imagens <strong>jpg</strong> e <strong>png</strong>.</span>
                        <span class="help-block js-banner-sizes">
                            @if ($groups->count() > 0 && $groups->first() && $size = $groups->first()->sizes->defaultSize())
                                Largura: <strong>{{ $size->width }}px</strong> - Altura: <strong>{{ $size->height }}px</strong>
                            @else
                                Largura: <strong>{{ Config::get('manager-banners::sizes.default.default.width') }}px</strong> - Altura: <strong>{{ Config::get('manager-banners::sizes.default.default.height') }}px</strong>
                            @endif
                        </span>
                    </div><!-- .col-sm-8 -->
                </div><!-- .form-group -->

                @if (! is_null($banner->banner))
                    <div class="form-group">
                        <label class="col-sm-2 control-label">Imagem Atual</label>

                        <div class="col-sm-8">
                            <img src="{{ asset($banner->getUrl() . '/manager-' . $banner->banner) }}" alt="" style="width: 150px">
                        </div><!-- .col-sm-8 -->
                    </div><!-- .form-group -->
                @endif

                @if (! in_array('expire_at', Config::get('manager-banners::hidden')))
                    <div class="form-group">
                        <label for="expire_at" class="col-sm-2 control-label">Banner expira em:</label>

                        <div class="col-sm-4">
                            <div class="input-group">
                                <span class="input-group-addon"><span class="glyphicon glyphicon-calendar"></span></span>
                                <input type="text" name="expire_at" id="expire_at" class="form-control" value="{{ ! is_null($banner->expire_at) ? date('d/m/Y', strtotime($banner->expire_at)) : null }}" data-datepicker maxlength="10">
                            </div>

                            <span class="help-block">Se uma data for selecionada, o banner deixará de ser exibido após esta data.</span>
                        </div><!-- .col-sm-8 -->
                    </div><!-- .form-group -->
                @endif
            @show
        </fieldset>

        <div class="form-group">
            <div class="col-sm-offset-2 col-sm-10">
                <button type="submit" class="btn btn-primary" data-loading-text="Salvando...">Salvar</button>
                <a href="{{ route('manager.banners.index') }}" class="btn">Cancelar</a>
            </div>
        </div><!-- .form-actions -->
    </form>
@stop

@section('scripts')
    @parent
    <script type="text/javascript" src="{{ asset('packages/escapework/manager-banners/assets/js/banners/form.js') }}"></script>
@stop
