@extends(Config::get('manager::views.layouts.master'))

@section('content')
    {{ Form::manager_breadcrumb(array('Banners')) }}

    {{
        Form::manager_page_header(
            'Banners',
            null,
            array(
                'route'    => route('manager.banners.create', array('banner_group_id' => Input::get('banner_group_id'))),
                'label'    => 'Inserir novo banner',
                'btn-type' => 'primary'
            )
        )
    }}

    @include('manager::inc.messages')

    @if ($groups->count() > 0 || in_array('expire_at', Config::get('manager-banners::hidden')))
        <form action="{{ route('manager.banners.index') }}" class="well form-inline" method="get" id="form-search">
            @if ($groups->count() > 0)
                <div class="form-group" style="margin-right: 10px">
                    <label>
                        {{ Form::select('banner_group_id', $groups->combobox(['empty_option' => true, 'empty_option_label' => 'Grupo de banner']), Input::get('banner_group_id'), ['id' => 'banner_group_id', 'class' => 'form-control']) }}
                    </label>
                </div>
            @endif

            <div class="checkbox" style="margin-right: 10px">
                <label>
                    <input type="checkbox" name="expired" value="1" {{ Input::get('expired') == 1 ? 'checked="checked"' : null }} /> &nbsp;
                    Buscar banners expirados
                </label>
            </div>

            <button type="submit" class="btn btn-primary"><i class="icon-search icon-white"></i> Buscar</button>
            <a class="btn btn-default" href="{{ route('manager.banners.index') }}">Limpar filtros</a>
        </form>
    @endif

    <p>Arraste os banners para alterar a ordem em que serão exibidos.</p>

    <table class="table table-bordered table-striped table-hover">
        <thead>
            <tr>
                <th></th>
                <th></th>
                <th>Banner</th>
                @if ($groups->count() > 0)
                    <th>Grupo</th>
                @endif
                <th>Ativo</th>
                <th width="15%">Ações</th>
            </tr>
        </thead>
        <tbody class="sortable">
            @foreach ($banners as $banner)
                <tr data-id="{{ $banner->id }}" class="{{ $banner->isExpired() ? 'error' : null }}" title="{{ $banner->isExpired() ? 'Este banner não está sendo exibido porque está com a data expirada' : null }}">
                    <td width="5%" style="text-align: center; vertical-align: middle; cursor: move">
                        <span class="glyphicon glyphicon-move"></span>
                    </td>
                    <td><img src="{{ asset($banner->getUrl() . '/manager-' . $banner->banner) }}" alt="{{ $banner->title }}" style="height: 30px" /></td>
                    <td>{{ $banner->title }}</td>
                    @if ($groups->count() > 0)
                        <td>{{ $banner->group ? $banner->group->title : null }}</td>
                    @endif
                    <td><input type="checkbox" value="1" data-id="{{ $banner->id }}" class="js-update-active" {{ $banner->active ? 'checked="checked"' : null }} /></td>
                    <td width="14%">
                        <div class="btn-group btn-group-sm">
                            <a href="{{ route('manager.banners.edit', $banner->id) }}" class="btn btn-default" title="Editar">
                                <span class="glyphicon glyphicon-pencil"></span> editar
                            </a>

                            <a href="{{ route('manager.banners.destroy', $banner->id) }}" class="btn btn-default" data-delete title="Excluir">
                                <span class="glyphicon glyphicon-trash"></span> excluir
                            </a>
                        </div>
                    </td>
                </tr>
            @endforeach
        </tbody>
    </table>
@stop

@section('scripts')
    @parent

    <script src="/packages/escapework/manager-banners/assets/js/banners/index.js"></script>
@stop
